@@ -2,7 +2,7 @@ import pandas as pd
 import numpy as np
 import datetime, random
 
-__version__ = '0.4.3' # master file
+__version__ = '0.5.0' # master file
 
 class AKIFlagger:
     ''' Main flagger to detect patients with acute kidney injury (AKI). This flagger returns patients with AKI according to the `KDIGO guidelines <https://kdigo.org/guidelines/>`_ on changes in creatinine\*. The KDIGO guidelines are as follows:
@@ -18,11 +18,11 @@ class AKIFlagger:
         
     Attributes:
         patient_id (string): **default 'mrn'.** Name of the column used to identify patients; e.g. 'PAT_MRN_ID'
-        encounter_id (string): **default 'enc'.** Name of the column used to identify encounters; e.g. 'PAT_ENC_CSN_ID'
+        encounter_id (string): **default 'enc'.** DEPRECATED; included for backwards compatibility. Name of the column used to identify encounters; e.g. 'PAT_ENC_CSN_ID'
         
         time (string): **default 'time'.** Name of the column containing time stamps; e.g. 'time'
         inpatient (string): **default 'inpatient'.** Name of the column containing inpatient/outpatient identifier; e.g. 'inpatient'
-        admission (string): **default 'admission'.** Name of the column containing the admission dates; e.g. 'admission'
+        admission (string): **default 'admission'.** DEPRECATED; included for backwards compatibility. Name of the column containing the admission dates; e.g. 'admission'
         creatinine (string): **default 'creatinine'.** Name of the column containing creatinine values; e.g. 'creatinine'
         
         age (string): **default 'age'.** Name of the column containing the age values; e.g. 'age'
@@ -51,10 +51,12 @@ class AKIFlagger:
     def __init__(self, patient_id = 'patient_id', creatinine = 'creatinine', time = 'time', inpatient = 'inpatient', # Required columns
                  baseline_creat = 'baseline_creat', # Helpful columns, imputed otherwise
                  age = 'age', sex = 'sex', race = 'race',  # Required if CKD-EPI imputation is wanted
-                 padding = None, HB_trumping = False, eGFR_impute = False, # Main parameters
+                 padding = '4hours', # Default padding of 4 hours, to account for delays in blood sample input draws
+                 RM_window = True, HB_trumping = False, eGFR_impute = False, # Main parameters
                  cond1time = '48hours', cond2time = '168hours', pad1time = '0hours', pad2time = '0hours', # Rolling window sizes
                 sort_values = True, add_baseline_creat = False, add_min_creat = False, 
-                add_imputed_admission = False, add_imputed_encounter = False): # Ancillary optional parameters (include output for intermediate calculations)
+                add_admission_col = False, add_imputed_encounter = False,
+                **defMapper): # Ancillary optional parameters (include output for intermediate calculations)
         
         # Columns necessary for calculation
         self.patient_id = patient_id
@@ -68,6 +70,7 @@ class AKIFlagger:
         self.race = race
         
         # Rolling-window variables
+        self.RM_window = RM_window
         self.pad1time = pad1time
         self.pad2time = pad2time
         if padding is not None:
@@ -83,7 +86,7 @@ class AKIFlagger:
         self.eGFR_impute = eGFR_impute
         
         # Extra options to specify what is included in the output
-        self.add_imputed_admission = add_imputed_admission
+        self.add_admission_col = add_admission_col
         self.add_imputed_encounter = add_imputed_encounter
         self.add_baseline_creat = add_baseline_creat
         self.add_min_creat = add_min_creat
@@ -101,6 +104,7 @@ class AKIFlagger:
         * *Stage 3:* 200% increase in (our tripling of) serum creatinine in < 7 days (168 hours)
 
         More information can be found in the documentation at `akiflagger.readthedocs.io <https://akiflagger.readthedocs.io/en/latest/>`_.
+        
         Args: 
             df (pd.DataFrame): Patient dataframe, should include some sort of patient and encounter identifier(s) and age, sex, race, serum creatinine and timestamps.
         Returns:
@@ -191,7 +195,7 @@ class AKIFlagger:
             mask_rw = np.logical_or(np.logical_and(~mask2d, mask_empty), np.logical_and(~mask_bc, mask_empty)) # The full mask is of all these conditions: admit to +2d, missed flagger, and non-null baseline creatinine values
             aki[mask_rw] = np.logical_or(c1[mask_rw], c2[mask_rw])*1
 
-            if not self.add_imputed_admission:
+            if not self.add_admission_col:
                 df = df.drop(self.admission, axis = 1)
             if not self.add_imputed_encounter:
                 df = df.drop(self.encounter_id, axis = 1)
@@ -214,14 +218,27 @@ class AKIFlagger:
     
     def addAdmissionEncounterColumns(self, dataframe):
         '''
-        Returns the admission (and possible encounter) column(s) in case the patient data frame is missing the admission/enc column.
+        Returns the admission column. An admission date is defined as the *first* timestamp where 2 consecutive inpatient creatinine measurements occur within 72 hrs. Id est:
+        --> inpatient
+        --> <= 72 hours
+        If there are two inpatient measurements but they are separated by more than 3 months, that would be considered a separate admission. 
+        
+        Args: 
+            dataframe (pd.DataFrame): Patient dataframe
+        Returns:
+            dataframe (pd.DataFrame): Patient dataframe with admission column added in 
+        
         '''
         self.admission = 'imputed_admission'
         self.encounter_id = 'imputed_encounter_id'
 
         tmp = dataframe.reset_index() # Reset index
         
-        # Admission column imputation
+        # Admission column imputation:
+        
+        # Admission is defined as the first timestamp where THIS occurs:
+        # two consecutive inpatient creatinine measurements <= 72 hours amart
+
         cond1 = tmp.groupby(self.patient_id)[self.time].diff(1).shift(-1) <= pd.Timedelta('72hours') # Time constraint check: ensure the inpatients grouped are w/ in 72 hours from each other
         cond2 = tmp[self.inpatient] & tmp.groupby(self.patient_id)[self.inpatient].shift(-1).astype('bool') # Chunk check: ensure that the True (inpatient) is followed by another True
         tmp['c1c2'] = cond1 & cond2
@@ -241,6 +258,14 @@ class AKIFlagger:
         '''Imputes the baseline creatinine values for those patients missing outpatient creatinine measurements from 365 to 7 days prior to admission.
         The imputation is based on the `CKD-EPI equation <https://www.niddk.nih.gov/health-information/professionals/clinical-tools-patient-management/kidney-disease/laboratory-evaluation/glomerular-filtration-rate/estimating>`_ from the paper
         *A New Equation to Estimate Glomerular Filtration Rate (Levey et. Al, 2009)*.
+        
+        The new equation used is Inker et. Al, 2021: https://www.nejm.org/doi/full/10.1056/NEJMoa2102953
+        
+        Args: 
+            age (int): age of patient
+            female (int): sex of patient; defaults to female (i.e. sex = 1 is female)
+            black (int): race of patient; black or not black... working on removing this from the analysis.
+        
         '''
 
         kappa = (0.9 - 0.2*female)
@@ -260,6 +285,8 @@ class AKIFlagger:
     def addBaselineCreat(self, dataframe):
         '''
         Returns baseline creatinine used in intermediate calculation for back-calculating AKI. Baseline creatinine is defined as the MEDIAN of OUTPATIENT creatinine values from 365 to 7 days prior to admission.
+        Args: 
+            
         '''
         # Baseline creatinine is defined as the MEDIAN of the OUTPATIENT creatinine values from 365 to 7 days prior to admission
 
@@ -341,7 +368,7 @@ def generate_toy_data(num_patients = 100, num_encounters_range = (1, 3), num_tim
         mrns = np.random.randint(10000, 20000, num_patients)
         admns = pd.to_datetime(np.random.randint(date_range[0], date_range[1], num_patients), unit = 's')
         encs = [np.random.randint(10000, 99999, np.random.randint(num_encounters_range[0],num_encounters_range[1])) for mrn, admn in zip(mrns, admns)]
-        creats = np.clip(np.random.normal(loc = 1, scale = creat_scale, size=num_patients), a_min = 0, a_max = None)
+        creats = np.clip(np.random.normal(loc = 1, scale = creat_scale, size=num_patients), a_min = 0, a_max = None) 
 
         #Combine the two dataframes
         d1 = pd.DataFrame([mrns, admns, creats]).T
@@ -392,5 +419,4 @@ def generate_toy_data(num_patients = 100, num_encounters_range = (1, 3), num_tim
         df = df.loc[:,[patient_id, inpatient, time, creatinine]]
         if printMsg:
             print('Successfully generated toy data!\n')
-        return df
-
+        return df
\ No newline at end of file
